@@ -5,4 +5,8 @@ from ._beat import Beatsignal,beatsignal
 
 from . import _callbacks as callbacks
 
-from . _marple_sequence import marple_sequence
\ No newline at end of file
+from . _marple_sequence import marple_sequence
+
+from .__modulated import modulated_signal
+
+from . import _modulated_utilits is modulations
