@@ -31,6 +31,7 @@ from ._math import(cexp,
 from ._geometry import (calc_line,
                         flip_vector,
                         ols_line,
-                        piecewise_ols_line)
+                        piecewise_ols_line,
+                        point_to_vector_distance)
 
 from ..operators import *
