@@ -55,7 +55,7 @@ def flip_vector(vector):
     fliped vector: 1d ndarray.        
     '''
     line = calc_line(vector)
-    return 2*line-freq_mod
+    return 2*line-vector
 #------------------------
 def ols_line(vector):
     '''
